# NICQS: No-Insulation Coil Quench Simulator

## Overview
- Python Thermo-electromagnetic modeling tool to simulate transients in No-Insulation (NI) HTS magnets.
- 2D, homogenized, python ODE solver.

## Development
- Python 3.11

## Standards
- Use type hints
- Add lots of comments and explain why certain methods are chosen.
- Max line length: 88 chars
- Prefer composition to inheritance
- No unicode
- For every added helper function, add a unit test.

## Context
- Use Windows CLI syntax by default.
- I am not always correct, try to be objective and point out potential mistakes.